import angr
import signal
import sys

TIMEOUT = 60

class TimeoutError(Exception):
    pass

def handler(signum, frame):
    raise TimeoutError

signal.signal(signal.SIGALRM, handler)
path = sys.argv[1]

try:
    signal.alarm(TIMEOUT)
    proj = angr.Project(path, auto_load_libs=False)
    cfg = proj.analyses.CFGFast()

    machine_instructions = 0
    ir_instructions = 0
    for node in cfg.nodes():
        block = node.block
        if block is None:
            continue

        machine_instructions += block.instructions
        ir_instructions += len(block.vex.statements)

    print("%s %d %d" % (path, machine_instructions, ir_instructions))
except TimeoutError:
    print("Timeout")
